@@ -1,5 +1,5 @@
 package WebService::Prismatic::InterestGraph;
-$WebService::Prismatic::InterestGraph::VERSION = '0.02';
+$WebService::Prismatic::InterestGraph::VERSION = '0.04';
 use 5.006;
 use Moo;
 use JSON qw(decode_json);
@@ -72,7 +72,7 @@ WebService::Prismatic::InterestGraph - identify topics in web page or text
 =head1 SYNOPSIS
 
  use WebService::Prismatic::InterestGraph;
- my $ig = WebService::Prismatic::InterestGraph->new( api_key => $key );
+ my $ig = WebService::Prismatic::InterestGraph->new( api_token => $key );
  my @tags = $ig->tag_url('http://perl.org');
 
  foreach my $tag (@tags) {
@@ -82,7 +82,7 @@ WebService::Prismatic::InterestGraph - identify topics in web page or text
 =head1 DESCRIPTION
 
 This module provides a simple interface to the Prismatic Interface Graph API,
-which is an alpha service provided by L<prismatic.com|http://prismatic.com>.
+which is an alpha service provided by L<getprismatic.com|http://getprismatic.com>.
 It takes a piece of text and returns a number of tags, each of which
 identifies a topic and a score for how likely the text includes that topic.
 The text can either be specified via a URL, or passed as a scalar.
@@ -100,11 +100,11 @@ you might be interested in reading.
 
 =head2 new
 
-The constructor takes an C<api_key>:
+The constructor takes an C<api_token>:
 
  use WebService::Prismatic::InterestGraph;
 
- my $ig = WebService::Prismatic::InterestGraph->new( api_key => $key );
+ my $ig = WebService::Prismatic::InterestGraph->new( api_token => $key );
 
 You can also pass an HTTP user agent with the C<ua> parameter,
 but it pretty much has to be an instance of L<HTTP::Tiny>.
